pypret.io package
=================

.. automodule:: pypret.io

Public interface
----------------
.. autoclass:: pypret.io.options.HDF5Options
.. autofunction:: pypret.io.save
.. autofunction:: pypret.io.load
.. autoclass:: pypret.io.IO
    :members:


Custom handlers
---------------

.. automodule:: pypret.io.handlers
    :no-members:
.. autoclass:: pypret.io.handlers.Handler
    :members:
.. autoclass:: pypret.io.handlers.TypeHandler
.. autoclass:: pypret.io.handlers.InstanceHandler
